## Ansættelseskontrakt

Mellem

<company-name>NordicSoft Solutions ApS</company-name>  
Vesterbrogade 44, 2. th., 6920 Videbæk  
CVR-nr.: 34567812

og

Sofie Maria Rasmussen  
Lodretvej 19, 3. tv., 8462 Harlev J  

indgås følgende ansættelsesaftale:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder ansættelsen pr. 01.08.2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted

Medarbejderens arbejdssted er NordicSoft Solutions ApS’ kontor, Vesterbrogade 44, 2. th., 6621 Gesten.
</location>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen ansættes som Frontend Udvikler.
</title>

## [SECTION-IDX]. Arbejdsopgaver

Hovedopgaverne omfatter:

- Udvikling og vedligeholdelse af webapplikationers brugergrænseflader
- Samarbejde med backend-udviklere og designere
- Deltagelse i planlægnings- og sprintmøder

Opgaverne kan justeres af virksomheden i takt med udviklingen af arbejdsopgaver og virksomhedens behov.

<trial-period>
Der er ikke aftalt en prøvetid i denne ansættelse.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige løn udgør kr. 540.000,00 brutto, svarende til kr. 45.000,00 brutto pr. måned. Lønnen udbetales bagud den sidste hverdag i måneden til medarbejderens NemKonto.

Lønnen kan reguleres efter årlig lønforhandling.
</salary>

<pension>
## [SECTION-IDX]. Pension

NordicSoft Solutions ApS opretter en pensionsordning for medarbejderen i Danica Pension. Virksomheden indbetaler 8% og medarbejderen 4% af lønnen til pensionsordningen.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler de lovpligtige sociale sikringsbidrag, herunder ATP og bidrag til barselsfonden, i henhold til gældende dansk lovgivning.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige ugentlige arbejdstid er 37 timer ekskl. frokost. Arbejdstiden placeres inden for NordicSoft Solutions ApS’ sædvanlige arbejdstid, og fastlægges i samråd med nærmeste leder.

Overarbejde honoreres ikke særskilt, men kan efter aftale afspadseres.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen har ret til ferie med løn efter ferielovens regler. Særligt ferietillæg på 1% udbetales én gang årligt.

Juleaftensdag (24. december) og Nytårsaftensdag (31. december) betragtes som fridage med fuld løn.
</holiday>

<extra-holiday>
Der ydes ikke ekstra feriefridage udover rettighederne efter ferieloven.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til relevant efter- og videreuddannelse i overensstemmelse med virksomhedens behov. Efteruddannelse aftales mellem medarbejderen og nærmeste leder.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal medarbejderen melde fravær til virksomheden så hurtigt som muligt. Ved fravær udover 3 dage kan virksomheden kræve dokumentation i form af lægeerklæring, som virksomheden betaler.

Medarbejderen har under sygdom ret til sin sædvanlige løn.
</illness>

<parental-leave>
## [SECTION-IDX]. Barsel, forældreorlov og adoption

Medarbejderen er berettiget til orlov i overensstemmelse med barselslovens bestemmelser.

Virksomheden betaler fuld løn til moderen i følgende perioder:
- 4 uger før forventet fødsel
- 14 uger efter fødslen

Faderen har ret til 2 ugers orlov med fuld løn efter fødslen.

Ved adoption gælder tilsvarende rettigheder, hvor det er relevant.
</parental-leave>

## [SECTION-IDX]. Barns sygdom

Medarbejderen har ret til 2 dages frihed med løn pr. barn pr. år i forbindelse med barns sygdom.

## [SECTION-IDX]. Multimedier

Virksomheden stiller relevant it-udstyr til rådighed for medarbejderen til brug i arbejdet. Privat anvendelse er tilladt indenfor de rammer, virksomheden fastsætter.

## [SECTION-IDX]. Fortrolighed og loyalitet

Der gælder fortrolighedspligt både under og efter ansættelsen vedrørende oplysninger om virksomheden, som ikke er alment kendte. Medarbejderen må ikke uberettiget viderebringe forretningshemmeligheder eller andre fortrolige forhold til tredjemand.

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsen kan opsiges af begge parter med 30 dages varsel til udgangen af en måned, jf. funktionærloven.

Opsigelsen skal være skriftlig og være modtageren i hænde senest den sidste kalenderdag i måneden.
</termination>

<collective-agreement>
Denne ansættelse er ikke omfattet af nogen kollektiv overenskomst.
</collective-agreement>

## [SECTION-IDX]. Retsgrundlag

Ansættelsesforholdet er reguleret af dansk ret. Hvor denne kontrakt ikke giver medarbejderen bedre rettigheder, følges funktionær- og ferielovens regler.

Videbæk, den 03.06.2024

Medarbejderen _____________________________________

Virksomheden _____________________________________